@@ -8,8 +8,6 @@ from .student_class_association import student_class_association
 from .tutor_class_association import tutor_class_association
 
 
-# TJTAG need to work through issues here, then copy these files to models module
-# circular import
 class Class(Base):
     """ Class Model for grouping teachers, students, and tutors """
     __tablename__ = "class"
@@ -24,4 +22,4 @@ class Class(Base):
 
     def __init__(self, name, teacher):
         self.name = name
-        self.tutor = tutor
+        self.teacher = teacher
